@@ -8,6 +8,10 @@ def attention(string):
     """
     return ret
 
+def log_getcwd():
+    import os
+    attention(f'{os.getcwd()}')
+
 hello = """
 ################################################################################
 ################################################################################
