@@ -11,4 +11,10 @@ def write_dotenv(env, file=".env"):
     """
     with open(".env", "w") as f:
         for i in env:
-            f.write(f'{i}={env[i]}\n')
\ No newline at end of file
+            f.write(f'{i}={env[i]}\n')
+
+def print_dict(dic:dict):
+    ret = ''
+    for i in dic:
+        ret = ret + f"""\n {i}: {dic[i]}"""
+    print(ret)
\ No newline at end of file
